This is the protocol describing the basic cache capability.
This is the protocol describing the basic cache capability.
(-base cache)Used to grab the underlying storage struct.
Used to grab the underlying storage struct.
(has? cache e)Checks if the cache contains a value associtaed with e
Checks if the cache contains a value associtaed with `e`
(hit cache e)Is meant to be called if the cache is determined to contain a value
associated with e
Is meant to be called if the cache is determined to contain a value associated with `e`
(lookup cache e)Retrieve the value associated with e if it exists
Retrieve the value associated with `e` if it exists
(miss cache e ret)Is meant to be called if the cache is determined to not contain a
value associated with e
Is meant to be called if the cache is determined to **not** contain a value associated with `e`
(seed cache base)Is used to signal that the cache should be created with a seed. The contract is that said cache should return an instance of its own type.
Is used to signal that the cache should be created with a seed. The contract is that said cache should return an instance of its own type.
(defcache cache-name fields & specifics)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |